@@ -239,11 +239,11 @@ class MediaCloud(object):
         stories_with_metadata = self._addMetadataTagsToStoryList(stories)
         return stories_with_metadata[0]
 
-    def storyRawCliffResults(self, story_id_list):
-        return self._queryForJson(self.V2_API_URL+'stories/cliff', {'stories_id': story_id_list})
+    def storyRawCliffResults(self, story_id_list, http_method='POST'):
+        return self._queryForJson(self.V2_API_URL+'stories/cliff', {'stories_id': story_id_list}, http_method)
 
-    def storyRawNytThemeResults(self, story_id_list):
-        return self._queryForJson(self.V2_API_URL+'stories/nytlabels', {'stories_id': story_id_list})
+    def storyRawNytThemeResults(self, story_id_list, http_method='POST'):
+        return self._queryForJson(self.V2_API_URL+'stories/nytlabels', {'stories_id': story_id_list}, http_method)
 
     def storyCount(self, solr_query='', solr_filter='', split=None, split_period=None, http_method='POST'):
         # The call returns the number of stories returned by Solr for the specified query
@@ -306,12 +306,14 @@ class MediaCloud(object):
         return self._queryForJson(self.V2_API_URL+'stories/corenlp',
                                   {'stories_id': story_id_list})
 
-    def storyWordMatrix(self, solr_query='', solr_filter='', rows=1000, max_words=None, stopword_length=None):
+    def storyWordMatrix(self, solr_query='', solr_filter='', rows=1000, max_words=None, stopword_length=None,
+                        old_stopwords=False):
         # Helpful to feed term-document-matrix driven analyses, like TF-IDF.
         params = dict()
         params['q'] = solr_query
         params['fq'] = solr_filter
         params['rows'] = rows
+        params['old_stopwords'] = 1 if old_stopwords else 0
         if max_words is not None:
             params['max_words'] = max_words
         if stopword_length is not None:
@@ -330,7 +332,8 @@ class MediaCloud(object):
         return self._queryForJson(self.V2_API_URL+'stories/tag_count', params, http_method)
 
     def wordCount(self, solr_query, solr_filter='', languages=None, num_words=500, sample_size=1000,
-                  include_stopwords=False, include_stats=False, ngram_size=1, random_seed=None, http_method='POST'):
+                  include_stopwords=False, include_stats=False, ngram_size=1, random_seed=None,
+                  old_stopwords=False, http_method='POST'):
         params = {
             'q': solr_query,
             'l': languages,
@@ -339,7 +342,8 @@ class MediaCloud(object):
             'include_stopwords': 1 if include_stopwords is True else 0,
             'include_stats': 1 if include_stats is True else 0,
             'ngram_size': ngram_size,
-            'random_seed': int(random_seed) if random_seed is not None else None
+            'random_seed': int(random_seed) if random_seed is not None else None,
+            'old_stopwords':  1 if old_stopwords else 0,
         }
         if solr_filter:
             params['fq'] = solr_filter
@@ -483,13 +487,28 @@ class MediaCloud(object):
         return r
 
     @staticmethod
+    @mediacloud.error.deprecated
     def publish_date_query(start_date, end_date, start_date_inclusive=True, end_date_inclusive=False,
                            field='publish_day'):
+        """
+        This is deprecated because the defaults didn't match what we use on the online tools, so it was causing
+        confusion. Use the `dates_as_query_clause` helper instead.
+        """
+        valid_date_fields = ['publish_day', 'publish_week', 'publish_month', 'publish_year']
+        if field not in valid_date_fields:
+            raise mediacloud.error.MCException("Not a valid date field {}".format(field))
+        return field+':' + _solr_date_range(start_date, end_date, start_date_inclusive, end_date_inclusive)
+
+    @staticmethod
+    def dates_as_query_clause(start_date, end_date, start_date_inclusive=True, end_date_inclusive=True,
+                           field='publish_day'):
         valid_date_fields = ['publish_day', 'publish_week', 'publish_month', 'publish_year']
         if field not in valid_date_fields:
             raise mediacloud.error.MCException("Not a valid date field {}".format(field))
         return field+':' + _solr_date_range(start_date, end_date, start_date_inclusive, end_date_inclusive)
 
+
+
     def topicMediaList(self, topics_id, **kwargs):
         params = {}
         valid_params = ['media_id', 'sort', 'name', 'limit',
@@ -1035,7 +1054,7 @@ class AdminMediaCloud(MediaCloud):
         return self._queryForJson(self.V2_API_URL+'topics/{}/list_snapshot_files'.format(topics_id), params)
 
 
-def _solr_date_range(start_date, end_date, start_date_inclusive=True, end_date_inclusive=False):
+def _solr_date_range(start_date, end_date, start_date_inclusive=True, end_date_inclusive=True):
     ret = ''
     if start_date_inclusive:
         ret += '['
